@@ -17,6 +17,13 @@ pub struct LineMatch {
 }
 
 impl LineMatch {
+    pub fn new(line_number: u64, ranges: Vec<(usize, usize)>) -> Self {
+        Self {
+            line_number,
+            ranges,
+        }
+    }
+
     pub fn lnum(line_number: u64) -> Self {
         Self {
             line_number,
@@ -48,6 +55,24 @@ impl File {
             contents: contents.into_boxed_slice(),
         }
     }
+
+    pub fn sample_file() -> Self {
+        let lmats = vec![
+            LineMatch::new(3, vec![(4, 7)]),
+            LineMatch::new(4, vec![(7, 10)]),
+        ];
+        let chunks = vec![(1, 7)];
+        let contents = b"\
+// Parse input as float number and print sqrt of it
+fn print_sqrt<S: AsRef<str>>(input: S) {
+    let result = input.as_ref().parse::<f64>();
+    if let Ok(f) = result {
+        println!(\"sqrt of {:.2} is {:.2}\", f, f.sqrt());
+    }
+}\
+        ";
+        Self::new(PathBuf::from("sample.rs"), lmats, chunks, contents.to_vec())
+    }
 }
 
 pub struct Files<I: Iterator> {
@@ -121,7 +146,7 @@ impl<I: Iterator<Item = Result<GrepMatch>>> Files<I> {
         &self,
         match_start: u64,
         match_end: u64,
-        lines: &mut impl Iterator<Item = Line<'contents>>,
+        lines: impl Iterator<Item = Line<'contents>>,
     ) -> (u64, u64) {
         let before_start = cmp::max(match_start.saturating_sub(self.max_context), 1);
         let before_end = cmp::max(match_start.saturating_sub(self.min_context), 1);
@@ -169,6 +194,11 @@ impl<I: Iterator<Item = Result<GrepMatch>>> Files<I> {
         }
         path
     }
+
+    fn error_item(&mut self, e: anyhow::Error) -> Option<Result<File>> {
+        self.saw_error = true;
+        Some(Err(e))
+    }
 }
 
 impl<I: Iterator<Item = Result<GrepMatch>>> Iterator for Files<I> {
@@ -185,17 +215,11 @@ impl<I: Iterator<Item = Result<GrepMatch>>> Iterator for Files<I> {
             ranges,
         } = match self.iter.next()? {
             Ok(m) => m,
-            Err(e) => {
-                self.saw_error = true;
-                return Some(Err(e));
-            }
+            Err(e) => return self.error_item(e),
         };
         let contents = match fs::read(&path) {
             Ok(vec) => vec,
-            Err(err) => {
-                self.saw_error = true;
-                return Some(Err(err.into()));
-            }
+            Err(err) => return self.error_item(err.into()),
         };
         // Assumes that matched lines are sorted by source location
         let mut lines = Lines::new(&contents);
@@ -220,6 +244,12 @@ impl<I: Iterator<Item = Result<GrepMatch>>> Iterator for Files<I> {
                     None => State::EndOfFile,
                     Some(Err(_)) => State::Error,
                     Some(Ok(m)) if m.path != path => State::EndOfFile,
+                    Some(Ok(m)) if m.line_number <= line_number => {
+                        // When the same line number is reported mutliple times, ignore the grep line.
+                        // This happens when reading output from `rg --vimgrep` (#13)
+                        self.iter.next();
+                        continue;
+                    }
                     Some(Ok(m)) if m.line_number - line_number >= self.max_context * 2 => {
                         State::EndOfChunk
                     }
@@ -231,15 +261,15 @@ impl<I: Iterator<Item = Result<GrepMatch>>> Iterator for Files<I> {
                     State::EndOfFile | State::EndOfChunk => chunks.push(
                         self.calculate_chunk_range(first_match_line, line_number, &mut lines),
                     ),
-                    State::Error => self.saw_error = true,
+                    State::Error => {
+                        let err = self.iter.next().unwrap().unwrap_err();
+                        return self.error_item(err);
+                    }
                     State::NextMatch => {
                         // Next match
                         let m = self.iter.next().unwrap().unwrap();
                         line_number = m.line_number;
-                        lmats.push(LineMatch {
-                            line_number,
-                            ranges: m.ranges,
-                        });
+                        lmats.push(LineMatch::new(line_number, m.ranges));
                     }
                 }
 
@@ -255,14 +285,10 @@ impl<I: Iterator<Item = Result<GrepMatch>>> Iterator for Files<I> {
             let m = self.iter.next().unwrap().unwrap();
             line_number = m.line_number;
             // First match line of next chunk
-            lmats.push(LineMatch {
-                line_number,
-                ranges: m.ranges,
-            });
+            lmats.push(LineMatch::new(line_number, m.ranges));
         }
 
         if chunks.is_empty() {
-            assert!(lmats.is_empty());
             return None;
         }
 
@@ -388,6 +414,33 @@ mod tests {
         assert_eq!(got[0], expected);
     }
 
+    #[test]
+    fn test_same_line_occurs_repeatedly() {
+        // Same line may be reported multiple times when reading output from `rg --vimgrep` (regression test for #17)
+
+        let mat = |lnum| {
+            Result::Ok(GrepMatch {
+                path: "Cargo.toml".into(),
+                line_number: lnum,
+                ranges: vec![],
+            })
+        };
+        let matches = [mat(1), mat(1), mat(1), mat(2), mat(2), mat(2)];
+
+        let mut files = Files::new(matches.into_iter(), 0, 0);
+        let File {
+            line_matches,
+            chunks,
+            ..
+        } = files.next().unwrap().unwrap();
+        assert!(files.next().is_none());
+
+        let want = vec![LineMatch::lnum(1), LineMatch::lnum(2)].into_boxed_slice();
+        assert_eq!(line_matches, want);
+        let want = vec![(1, 1), (2, 2)].into_boxed_slice();
+        assert_eq!(chunks, want);
+    }
+
     #[test]
     fn test_error_while_matching() {
         #[derive(Debug)]
@@ -399,10 +452,21 @@ mod tests {
         }
         impl std::error::Error for DummyError {}
 
-        let matches: Vec<Result<GrepMatch>> = vec![Err(Error::new(DummyError))];
-        let err = Files::new(matches.into_iter(), 3, 6)
-            .collect::<Result<Vec<_>>>()
-            .unwrap_err();
-        assert_eq!(format!("{}", err), "dummy error!");
+        for matches in [
+            vec![Err(Error::new(DummyError))], // Error at first match
+            vec![
+                Ok(GrepMatch {
+                    path: "Cargo.toml".into(),
+                    line_number: 1,
+                    ranges: vec![],
+                }),
+                Err(Error::new(DummyError)), // Error at second match
+            ],
+        ] {
+            let err = Files::new(matches.into_iter(), 3, 6)
+                .collect::<Result<Vec<_>>>()
+                .unwrap_err();
+            assert_eq!(format!("{}", err), "dummy error!");
+        }
     }
 }
