@@ -1,5 +1,5 @@
 use anyhow::{Context, Result};
-use clap::{Arg, Command};
+use clap::{Arg, ArgAction, Command};
 use hgrep::grep::BufReadExt;
 use hgrep::printer::{PrinterOptions, TextWrapMode};
 use std::cmp;
@@ -56,11 +56,13 @@ fn command() -> Command {
             Arg::new("no-grid")
                 .short('G')
                 .long("no-grid")
+                .action(ArgAction::SetTrue)
                 .help("Remove borderlines for more compact output"),
         )
         .arg(
             Arg::new("grid")
                 .long("grid")
+                .action(ArgAction::SetTrue)
                 .help("Add borderlines to output. This flag is an opposite of --no-grid"),
         )
         .arg(
@@ -81,6 +83,7 @@ fn command() -> Command {
         .arg(
             Arg::new("list-themes")
                 .long("list-themes")
+                .action(ArgAction::SetTrue)
                 .help("List all available theme names and their samples. Samples show the output where 'let' is searched. The names can be used at --theme option"),
         )
         .arg(
@@ -110,6 +113,7 @@ fn command() -> Command {
             Arg::new("first-only")
                 .short('f')
                 .long("first-only")
+                .action(ArgAction::SetTrue)
                 .help("Show only the first code snippet per file")
         )
         .arg(
@@ -126,6 +130,7 @@ fn command() -> Command {
     let cmd = cmd.arg(
         Arg::new("custom-assets")
             .long("custom-assets")
+            .action(ArgAction::SetTrue)
             .help("Load bat's custom assets. Note that this flag may not work with some version of `bat` command. This flag is only for bat printer"),
     );
 
@@ -134,12 +139,16 @@ fn command() -> Command {
         .arg(
             Arg::new("background")
                 .long("background")
+                .action(ArgAction::SetTrue)
                 .help("Paint background colors. This flag is only for syntect printer"),
         )
         .arg(
-            Arg::new("ascii-lines").long("ascii-lines").help(
-                "Use ASCII characters for drawing border lines instead of Unicode characters",
-            ),
+            Arg::new("ascii-lines")
+                .long("ascii-lines")
+                .action(ArgAction::SetTrue)
+                .help(
+                    "Use ASCII characters for drawing border lines instead of Unicode characters",
+                ),
         );
 
     #[cfg(feature = "ripgrep")]
@@ -156,24 +165,28 @@ fn command() -> Command {
             .arg(
                 Arg::new("no-ignore")
                     .long("no-ignore")
+                    .action(ArgAction::SetTrue)
                     .help("Don't respect ignore files (.gitignore, .ignore, etc.)"),
             )
             .arg(
                 Arg::new("ignore-case")
                     .short('i')
                     .long("ignore-case")
+                    .action(ArgAction::SetTrue)
                     .help("When this flag is provided, the given pattern will be searched case insensitively"),
             )
             .arg(
                 Arg::new("smart-case")
                     .short('S')
                     .long("smart-case")
+                    .action(ArgAction::SetTrue)
                     .help("Search case insensitively if the pattern is all lowercase. Search case sensitively otherwise"),
             )
             .arg(
                 Arg::new("hidden")
                     .short('.')
                     .long("hidden")
+                    .action(ArgAction::SetTrue)
                     .help("Search hidden files and directories. By default, hidden files and directories are skipped"),
             )
             .arg(
@@ -189,45 +202,53 @@ fn command() -> Command {
             .arg(
                 Arg::new("glob-case-insensitive")
                     .long("glob-case-insensitive")
+                    .action(ArgAction::SetTrue)
                     .help("Process glob patterns given with the -g/--glob flag case insensitively"),
             )
             .arg(
                 Arg::new("fixed-strings")
                     .short('F')
                     .long("fixed-strings")
+                    .action(ArgAction::SetTrue)
                     .help("Treat the pattern as a literal string instead of a regular expression"),
             )
             .arg(
                 Arg::new("word-regexp")
                     .short('w')
                     .long("word-regexp")
+                    .action(ArgAction::SetTrue)
                     .help("Only show matches surrounded by word boundaries"),
             )
             .arg(
                 Arg::new("follow-symlink")
                     .short('L')
                     .long("follow")
+                    .action(ArgAction::SetTrue)
                     .help("When this flag is enabled, hgrep will follow symbolic links while traversing directories"),
             )
             .arg(
                 Arg::new("multiline")
                     .short('U')
                     .long("multiline")
+                    .action(ArgAction::SetTrue)
                     .help("Enable matching across multiple lines"),
             )
             .arg(
                 Arg::new("multiline-dotall")
                     .long("multiline-dotall")
+                    .action(ArgAction::SetTrue)
                     .help("Enable \"dot all\" in your regex pattern, which causes '.' to match newlines when multiline searching is enabled"),
             )
             .arg(
                 Arg::new("crlf")
                     .long("crlf")
+                    .action(ArgAction::SetTrue)
                     .help(r"When enabled, hgrep will treat CRLF ('\r\n') as a line terminator instead of just '\n'. This flag is useful on Windows"),
             )
             .arg(
                 Arg::new("mmap")
                     .long("mmap")
+                    .action(ArgAction::SetTrue)
                     .help("Search using memory maps when possible. mmap is disabled by default unlike ripgrep"),
             )
             .arg(
@@ -249,12 +270,14 @@ fn command() -> Command {
                 Arg::new("line-regexp")
                     .short('x')
                     .long("line-regexp")
+                    .action(ArgAction::SetTrue)
                     .help("Only show matches surrounded by line boundaries. This is equivalent to putting ^...$ around the search pattern"),
             )
             .arg(
                 Arg::new("pcre2")
                     .short('P')
                     .long("pcre2")
+                    .action(ArgAction::SetTrue)
                     .help("When this flag is present, hgrep will use the PCRE2 regex engine instead of its default regex engine"),
             )
             .arg(
@@ -278,6 +301,7 @@ fn command() -> Command {
             .arg(
                 Arg::new("type-list")
                     .long("type-list")
+                    .action(ArgAction::SetTrue)
                     .help("Show all supported file types and their corresponding globs"),
             )
             .arg(
@@ -291,16 +315,19 @@ fn command() -> Command {
                 Arg::new("invert-match")
                     .short('v')
                     .long("invert-match")
+                    .action(ArgAction::SetTrue)
                     .help("Invert matching. Show lines that do not match the given pattern"),
             )
             .arg(
                 Arg::new("one-file-system")
                     .long("one-file-system")
+                    .action(ArgAction::SetTrue)
                     .help("When enabled, the search will not cross file system boundaries relative to where it started from"),
             )
             .arg(
                 Arg::new("no-unicode")
                     .long("no-unicode")
+                    .action(ArgAction::SetTrue)
                     .help("Disable unicode-aware regular expression matching"),
             )
             .arg(
@@ -364,23 +391,23 @@ fn build_ripgrep_config(
     config
         .min_context(min_context)
         .max_context(max_context)
-        .no_ignore(matches.contains_id("no-ignore"))
-        .hidden(matches.contains_id("hidden"))
-        .case_insensitive(matches.contains_id("ignore-case"))
-        .smart_case(matches.contains_id("smart-case"))
-        .glob_case_insensitive(matches.contains_id("glob-case-insensitive"))
-        .pcre2(matches.contains_id("pcre2")) // must be before fixed_string
-        .fixed_strings(matches.contains_id("fixed-strings"))
-        .word_regexp(matches.contains_id("word-regexp"))
-        .follow_symlink(matches.contains_id("follow-symlink"))
-        .multiline(matches.contains_id("multiline"))
-        .crlf(matches.contains_id("crlf"))
-        .multiline_dotall(matches.contains_id("multiline-dotall"))
-        .mmap(matches.contains_id("mmap"))
-        .line_regexp(matches.contains_id("line-regexp"))
-        .invert_match(matches.contains_id("invert-match"))
-        .one_file_system(matches.contains_id("one-file-system"))
-        .no_unicode(matches.contains_id("no-unicode"));
+        .no_ignore(matches.get_flag("no-ignore"))
+        .hidden(matches.get_flag("hidden"))
+        .case_insensitive(matches.get_flag("ignore-case"))
+        .smart_case(matches.get_flag("smart-case"))
+        .glob_case_insensitive(matches.get_flag("glob-case-insensitive"))
+        .pcre2(matches.get_flag("pcre2")) // must be before fixed_string
+        .fixed_strings(matches.get_flag("fixed-strings"))
+        .word_regexp(matches.get_flag("word-regexp"))
+        .follow_symlink(matches.get_flag("follow-symlink"))
+        .multiline(matches.get_flag("multiline"))
+        .crlf(matches.get_flag("crlf"))
+        .multiline_dotall(matches.get_flag("multiline-dotall"))
+        .mmap(matches.get_flag("mmap"))
+        .line_regexp(matches.get_flag("line-regexp"))
+        .invert_match(matches.get_flag("invert-match"))
+        .one_file_system(matches.get_flag("one-file-system"))
+        .no_unicode(matches.get_flag("no-unicode"));
 
     if let Some(globs) = matches.get_many::<String>("glob") {
         config.globs(globs.map(String::as_str));
@@ -490,7 +517,7 @@ fn app() -> Result<bool> {
         printer_opts.theme = Some(theme);
     }
 
-    let is_grid = matches.contains_id("grid");
+    let is_grid = matches.get_flag("grid");
     #[cfg(feature = "bat-printer")]
     if printer_kind == PrinterKind::Bat {
         if let Ok("plain" | "header" | "numbers") =
@@ -501,7 +528,7 @@ fn app() -> Result<bool> {
             }
         }
     }
-    if matches.contains_id("no-grid") && !is_grid {
+    if matches.get_flag("no-grid") && !is_grid {
         printer_opts.grid = false;
     }
 
@@ -525,13 +552,13 @@ fn app() -> Result<bool> {
         }
     }
 
-    if matches.contains_id("first-only") {
+    if matches.get_flag("first-only") {
         printer_opts.first_only = true;
     }
 
     #[cfg(feature = "syntect-printer")]
     {
-        if matches.contains_id("background") {
+        if matches.get_flag("background") {
             printer_opts.background_color = true;
             #[cfg(feature = "bat-printer")]
             if printer_kind == PrinterKind::Bat {
@@ -539,7 +566,7 @@ fn app() -> Result<bool> {
             }
         }
 
-        if matches.contains_id("ascii-lines") {
+        if matches.get_flag("ascii-lines") {
             printer_opts.ascii_lines = true;
             #[cfg(feature = "bat-printer")]
             if printer_kind == PrinterKind::Bat {
@@ -549,7 +576,7 @@ fn app() -> Result<bool> {
     }
 
     #[cfg(feature = "bat-printer")]
-    if matches.contains_id("custom-assets") {
+    if matches.get_flag("custom-assets") {
         printer_opts.custom_assets = true;
         #[cfg(feature = "syntect-printer")]
         if printer_kind == PrinterKind::Syntect {
@@ -557,7 +584,7 @@ fn app() -> Result<bool> {
         }
     }
 
-    if matches.contains_id("list-themes") {
+    if matches.get_flag("list-themes") {
         #[cfg(feature = "syntect-printer")]
         if printer_kind == PrinterKind::Syntect {
             hgrep::syntect::list_themes(io::stdout().lock(), &printer_opts)?;
@@ -574,7 +601,7 @@ fn app() -> Result<bool> {
     }
 
     #[cfg(feature = "ripgrep")]
-    if matches.contains_id("type-list") {
+    if matches.get_flag("type-list") {
         let config = build_ripgrep_config(min_context, max_context, &matches)?;
         config.print_types(io::stdout().lock())?;
         return Ok(true);
